@@ -5,6 +5,8 @@ use Net::Google::DataAPI::Auth::AuthSub;
 use Net::Google::AuthSub;
 use URI;
 
+our $VERSSION = '0.02';
+
 role_type 'Net::Google::DataAPI::Types::Auth'
     => {role => 'Net::Google::DataAPI::Role::Auth'};
 
@@ -26,4 +28,9 @@ coerce 'Net::Google::DataAPI::Types::URI'
     => from 'Str'
     => via { URI->new(( m{://} ) ? $_ : ('http://'.$_)) };
 
+__PACKAGE__->meta->make_immutable;
+
+no Any::Moose;
+no Any::Moose '::Util::TypeConstraints';
+
 1;
